@@ -2,26 +2,22 @@ from .checks import LspSpecificationWarning
 from .client import LanguageClient
 from .client import __version__
 from .client import client_capabilities
-from .client import make_test_client
-from .plugin import ClientServer
+from .client import make_test_lsp_client
 from .plugin import ClientServerConfig
 from .plugin import fixture
-from .plugin import make_client_server
+from .plugin import pytest_addoption
 from .plugin import pytest_runtest_makereport
-from .plugin import pytest_runtest_setup
 from .protocol import LanguageClientProtocol
 
 __all__ = [
     "__version__",
-    "ClientServer",
     "ClientServerConfig",
     "LanguageClient",
     "LanguageClientProtocol",
     "LspSpecificationWarning",
     "client_capabilities",
     "fixture",
-    "make_client_server",
-    "make_test_client",
+    "make_test_lsp_client",
+    "pytest_addoption",
     "pytest_runtest_makereport",
-    "pytest_runtest_setup",
 ]
